Skip to Content.
Sympa Menu

ndt-dev - [ndt] r304 committed - change alarm() time from 60 sec to 120 sec. This alarm is suppose to ...

Subject: NDT-DEV email list created

List archive

[ndt] r304 committed - change alarm() time from 60 sec to 120 sec. This alarm is suppose to ...


Chronological Thread 
  • From:
  • To:
  • Subject: [ndt] r304 committed - change alarm() time from 60 sec to 120 sec. This alarm is suppose to ...
  • Date: Sun, 28 Feb 2010 19:52:20 +0000

Revision: 304
Author: rcarlson501
Date: Sun Feb 28 11:51:47 2010
Log: change alarm() time from 60 sec to 120 sec. This alarm is suppose to
prevent clients from remaining stuck in the queue forever, but the
normal queue walking process should provide that protection. This
alarm() may be removed in the near future.

RAC -2.28.10


http://code.google.com/p/ndt/source/detail?r=304

Modified:
/trunk/src/web100srv.c

=======================================
--- /trunk/src/web100srv.c Sun Feb 28 11:29:32 2010
+++ /trunk/src/web100srv.c Sun Feb 28 11:51:47 2010
@@ -2231,9 +2231,9 @@
testopt.c2sopt = TOPT_ENABLED;
if (t_opts & TEST_S2C)
testopt.s2copt = TOPT_ENABLED;
- alarm(60); /* die in 30 seconds, but only if a test doesn't get started
+ alarm(120); /* die in 120 seconds, but only if a test doesn't get started
* reset alarm() before every test */
- log_println(6, "setting master alarm() to 60 seconds, tests must start (complete?) before this timer expires");
+ log_println(6, "setting master alarm() to 120 seconds, tests must start (complete?) before this timer expires");

if (strncmp(test_suite, "Invalid", 7) != 0) {
log_println(3, "Valid test sequence requested, run test for client=%d", getpid());


  • [ndt] r304 committed - change alarm() time from 60 sec to 120 sec. This alarm is suppose to ..., ndt, 02/28/2010

Archive powered by MHonArc 2.6.16.

Top of Page